@@ -10,9 +10,9 @@
 finite_difference = function(x, S) {
   n = length(x)
   fdx <- vector(length = n)
-  fdx[1] = (x[2]-x[1])/S # first derivative
-  for (i in 3:(n-1)) {
-    fdx[i-2] = (x[i] - x[i-2]) / (2*S) # the intermediate ones
+  fdx[1] = (x[2]-x[1]) / S # first derivative
+  for (i in 3:n) {
+    fdx[i-1] = (x[i] - x[i-2]) / (2 * S) # the intermediate ones
   }
   fdx[n] = (x[n] - x[n - 1]) / S # the last one
   return(fdx) # exchange envelopes
